summaryrefslogtreecommitdiffstats
path: root/drivers/vulkan/rendering_device_driver_vulkan.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/vulkan/rendering_device_driver_vulkan.cpp')
-rw-r--r--drivers/vulkan/rendering_device_driver_vulkan.cpp14
1 files changed, 8 insertions, 6 deletions
diff --git a/drivers/vulkan/rendering_device_driver_vulkan.cpp b/drivers/vulkan/rendering_device_driver_vulkan.cpp
index 6eecd850f5..3643f599d9 100644
--- a/drivers/vulkan/rendering_device_driver_vulkan.cpp
+++ b/drivers/vulkan/rendering_device_driver_vulkan.cpp
@@ -2,9 +2,11 @@
/* rendering_device_driver_vulkan.cpp */
/**************************************************************************/
/* This file is part of: */
-/* GODOT ENGINE */
-/* https://godotengine.org */
+/* REDOT ENGINE */
+/* https://redotengine.org */
/**************************************************************************/
+/* Copyright (c) 2024-present Redot Engine contributors */
+/* (see REDOT_AUTHORS.md) */
/* Copyright (c) 2014-present Godot Engine contributors (see AUTHORS.md). */
/* Copyright (c) 2007-2014 Juan Linietsky, Ariel Manzur. */
/* */
@@ -612,7 +614,7 @@ Error RenderingDeviceDriverVulkan::_check_device_features() {
// Check for required features.
if (!physical_device_features.imageCubeArray || !physical_device_features.independentBlend) {
- String error_string = vformat("Your GPU (%s) does not support the following features which are required to use Vulkan-based renderers in Godot:\n\n", context_device.name);
+ String error_string = vformat("Your GPU (%s) does not support the following features which are required to use Vulkan-based renderers in Redot:\n\n", context_device.name);
if (!physical_device_features.imageCubeArray) {
error_string += "- No support for image cube arrays.\n";
}
@@ -777,7 +779,7 @@ Error RenderingDeviceDriverVulkan::_check_device_capabilities() {
if (use_1_2_features) {
#ifdef MACOS_ENABLED
- ERR_FAIL_COND_V_MSG(!device_features_vk_1_2.shaderSampledImageArrayNonUniformIndexing, ERR_CANT_CREATE, "Your GPU doesn't support shaderSampledImageArrayNonUniformIndexing which is required to use the Vulkan-based renderers in Godot.");
+ ERR_FAIL_COND_V_MSG(!device_features_vk_1_2.shaderSampledImageArrayNonUniformIndexing, ERR_CANT_CREATE, "Your GPU doesn't support shaderSampledImageArrayNonUniformIndexing which is required to use the Vulkan-based renderers in Redot.");
#endif
if (enabled_device_extension_names.has(VK_KHR_SHADER_FLOAT16_INT8_EXTENSION_NAME)) {
shader_capabilities.shader_float16_is_supported = device_features_vk_1_2.shaderFloat16;
@@ -2601,7 +2603,7 @@ Error RenderingDeviceDriverVulkan::command_queue_execute_and_present(CommandQueu
// Handling VK_SUBOPTIMAL_KHR the same as VK_SUCCESS is completely intentional.
//
// Godot does not currently support native rotation in Android when creating the swap chain. It intentionally uses
// VK_SURFACE_TRANSFORM_IDENTITY_BIT_KHR instead of the current transform bits available in the surface capabilities.
// Choosing the transform that leads to optimal presentation leads to distortion that makes the application unusable,
// as the rotation of all the content is not handled at the moment.
@@ -3424,7 +3426,7 @@ Vector<uint8_t> RenderingDeviceDriverVulkan::shader_compile_binary_from_spirv(Ve
binptr[0] = 'G';
binptr[1] = 'S';
binptr[2] = 'B';
- binptr[3] = 'D'; // Godot Shader Binary Data.
+ binptr[3] = 'D'; // Redot Shader Binary Data.
offset += 4;
encode_uint32(ShaderBinary::VERSION, binptr + offset);
offset += sizeof(uint32_t);
@@ -2601,7 +2603,7 @@ Error RenderingDeviceDriverVulkan::command_queue_execute_and_present(CommandQueu
// Handling VK_SUBOPTIMAL_KHR the same as VK_SUCCESS is completely intentional.
//
- // Godot does not currently support native rotation in Android when creating the swap chain. It intentionally uses
+ // Redot does not currently support native rotation in Android when creating the swap chain. It intentionally uses
// VK_SURFACE_TRANSFORM_IDENTITY_BIT_KHR instead of the current transform bits available in the surface capabilities.
// Choosing the transform that leads to optimal presentation leads to distortion that makes the application unusable,